<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>Dialog</name>
    <message>
        <location filename="." line="144"/>
        <source>Préférences de pyMecaVideo</source>
        <translation type="obsolete">Preferencias de pyMecaVideo</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Échelle des vitesses (px pour 1m/s)</source>
        <translation type="obsolete">Escala de velocidades (px para 1m/s)</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Vitesses affichées</source>
        <translation type="obsolete">Velocidades mostradas</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Afficheur vidéo</source>
        <translation type="obsolete">Display video</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Niveau de verbosité (débogage)</source>
        <translation type="obsolete">Nivel de debug</translation>
    </message>
</context>
<context>
    <name>Label_Echelle</name>
    <message>
        <location filename="." line="144"/>
        <source>Choisir le nombre de points puis &quot;DÃ©marrer l&apos;acquisition&quot; </source>
        <translation type="obsolete">Escojer el número de puntos y &quot;iniciar la acquisición&quot;</translation>
    </message>
</context>
<context>
    <name>StartQT4</name>
    <message>
        <location filename="pymecavideo.py" line="379"/>
        <source>indÃ©f.</source>
        <translation type="obsolete">indéf.</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>chemin vers les modules : %s</source>
        <translation type="obsolete">Carpeta de los Módulos</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1041"/>
        <source>temps en seconde, positions en mÃ¨tre</source>
        <translation type="obsolete">tiempo en segundos, posición en metros</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>point NÂ° </source>
        <translation type="obsolete">Point N° </translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Cliquer sur le point NÂ°%d</source>
        <translation type="obsolete">Clic en el punto N° :</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1518"/>
        <source>DÃ©finir une Ã©chelle</source>
        <translation type="obsolete">Definir la escala</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1518"/>
        <source>Quelle est la longueur en mÃ¨tre de votre Ã©talon sur l&apos;image ?</source>
        <translation type="obsolete">¿Cuál es el tamaño , en metros de su calibrador en la imagen?</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1536"/>
        <source> Merci d&apos;indiquer une Ã©chelle valable</source>
        <translation type="obsolete">Usted tiene que dar una escala válida</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1592"/>
        <source>Les donnÃ©es seront perdues</source>
        <translation type="obsolete">Los datos serán perdidos</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1592"/>
        <source>Votre travail n&apos;a pas Ã©tÃ© sauvegardÃ©
Voulez-vous les sauvegarder ?</source>
        <translation type="obsolete">Su trabajo no ha sido guardado.
¿Quiere Usted guardarlo ahora?</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1614"/>
        <source>Vous avez atteint le dÃ©but de la vidÃ©o</source>
        <translation type="obsolete">Usted alcanzó el principio del video</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1650"/>
        <source>Ouvrir une vidÃ©o</source>
        <translation type="obsolete">Abrir un video</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1645"/>
        <source>Nom de fichier non conforme</source>
        <translation type="obsolete">Nombre de archivo no valido</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Le nom de votre fichier contient des caractÃ¨res accentuÃ©s ou des espaces.
 Merci de bien vouloir le renommer avant de continuer</source>
        <translation type="obsolete">El nombre de su archivo contiene caracteres con acentos o espacios. Por favor retirenlos antes de seguir.</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1677"/>
        <source>Veuillez choisir une image et dÃ©finir l&apos;Ã©chelle</source>
        <translation type="obsolete">Usted debe escojer una imagen y definir la escala</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>DÃ©solÃ© pas de fichier d&apos;aide pour ce langage %s.</source>
        <translation type="obsolete">Lo siento, no hay archivo de ayuda para este idioma</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Impossible de lire %s</source>
        <translation type="obsolete">Imposible de leer %s</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Usage : pymecavideo [-f fichier | --fichier_pymecavideo=fichier]</source>
        <translation type="obsolete">Uso : pymecavideo [-f fichier | --fichier_pymecavideo=fichier]</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>point NÂ°</source>
        <translation type="obsolete">punto N°</translation>
    </message>
</context>
<context>
    <name>pymecavideo</name>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="37"/>
        <source>PyMecaVideo, analyse mécanique des vidéos</source>
        <translation type="obsolete">PyMecaVideo, análisis mecánica de los videos</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="86"/>
        <source>Acquisition des données</source>
        <translation type="obsolete">Acquisición de datos</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="189"/>
        <source>Pas de vidéos chargées</source>
        <translation type="obsolete">No se ha cargado ningún video</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Bienvenue sur pymeca vidéo, pas d&apos;images chargée</source>
        <translation type="obsolete">Bienvenidos en pymecavideo, no se ha cargado ningún video</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="551"/>
        <source>Définir l&apos;échelle</source>
        <translation type="obsolete">Definir la escala</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="229"/>
        <source>Image n°</source>
        <translation type="obsolete">Imagen n°</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Nombre de points à étudier</source>
        <translation type="obsolete">Numero de puntos a estudiar</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="370"/>
        <source>indéf.</source>
        <translation>indef.</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="564"/>
        <source>px/m</source>
        <translation type="obsolete">px/m</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Démarrer l&apos;acquisition</source>
        <translation type="obsolete">Iniciar la acquisiciónf</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="535"/>
        <source>Tout réinitialiser</source>
        <translation type="obsolete">Reinicializar a todo</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>efface le point précédent</source>
        <translation type="obsolete">elimina el punto precedente</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="455"/>
        <source>rétablit le point suivant</source>
        <translation type="obsolete">recupera el punto precedente</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>trajectoires et mesures</source>
        <translation type="obsolete">trayectorias y medidas</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Origine du référentiel :</source>
        <translation type="obsolete">Origen del referencial</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Vidéo calculée</source>
        <translation type="obsolete">Video calculado</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>V. normale</source>
        <translation type="obsolete">V. normal</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>ralenti /2</source>
        <translation type="obsolete">velocidad 1/2</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>ralenti /4</source>
        <translation type="obsolete">velocidad 1/4</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>ralenti /8</source>
        <translation type="obsolete">velocidad 1/8</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Échelle de vitesses :</source>
        <translation type="obsolete">Escala de velocidades</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="832"/>
        <source>px pour 1 m/s</source>
        <translation type="obsolete">px para 1 m/s</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="972"/>
        <source>Coordonnées</source>
        <translation type="obsolete">Coordenadas</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="984"/>
        <source>Copier les mesures dans le presse papier</source>
        <translation type="obsolete">Copiar medidas </translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Fichier</source>
        <translation type="obsolete">Archivo</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Aide</source>
        <translation type="obsolete">Ayuda</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Édition</source>
        <translation type="obsolete">Edicion</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2011"/>
        <source>Ouvrir une vidéo</source>
        <translation type="unfinished">Abrir un video</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1110"/>
        <source>avanceimage</source>
        <translation type="obsolete">adelanta imagen</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1115"/>
        <source>reculeimage</source>
        <translation type="obsolete">retraza imagen</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Quitter</source>
        <translation type="obsolete">Salir</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Enregistrer les données</source>
        <translation type="obsolete">Guardar datos</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>À propos</source>
        <translation type="obsolete">About</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Rouvrir un fichier mecavidéo</source>
        <translation type="obsolete">Reabrir un archivo mecavideo</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Préférences</source>
        <translation type="obsolete">Preferencias</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>copier dans le presse-papier</source>
        <translation type="obsolete">copiar</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1562"/>
        <source>Choisir ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="296"/>
        <source>indÃ©f</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="994"/>
        <source>Ouvrir un projet Pymecavideo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="994"/>
        <source>fichiers pymecavideo(*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1300"/>
        <source>temps en seconde, positions en mÃ¨tre</source>
        <translation type="unfinished">tiempo en segundos, posición en metros</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1665"/>
        <source>Vous avez atteint la fin de la vidÃ©o</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1871"/>
        <source>DÃ©finir une Ã©chelle</source>
        <translation type="unfinished">Definir la escala</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1871"/>
        <source>Quelle est la longueur en mÃ¨tre de votre Ã©talon sur l&apos;image ?</source>
        <translation type="unfinished">¿Cuál es el tamaño , en metros de su calibrador en la imagen?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1892"/>
        <source> Merci d&apos;indiquer une Ã©chelle valable</source>
        <translation type="unfinished">Usted tiene que dar una escala válida</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1948"/>
        <source>Les donnÃ©es seront perdues</source>
        <translation type="unfinished">Los datos serán perdidos</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1948"/>
        <source>Votre travail n&apos;a pas Ã©tÃ© sauvegardÃ©
Voulez-vous les sauvegarder ?</source>
        <translation type="unfinished">Su trabajo no ha sido guardado.
¿Quiere Usted guardarlo ahora?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1782"/>
        <source>Vous avez atteint le dÃ©but de la vidÃ©o</source>
        <translation type="obsolete">Usted alcanzó el principio del video</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2006"/>
        <source>Nom de fichier non conforme</source>
        <translation type="unfinished">Nombre de archivo no valido</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1862"/>
        <source>Veuillez choisir une image et dÃ©finir l&apos;Ã©chelle</source>
        <translation type="obsolete">Usted debe escojer una imagen y definir la escala</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1992"/>
        <source>fichiers vidÃ©os ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="502"/>
        <source>Enregistrer la chronophotographie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="502"/>
        <source>fichiers images(*.png *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1393"/>
        <source>Veuillez sÃ©lectionner un cadre autour de(s) l&apos;objet(s) que vous voulez suivre.
Vous pouvez arrÃªter Ã&#xa0; tous moments la capture en appuyant sur le bouton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2006"/>
        <source>Le nom de votre fichier contient des caractÃ¨res accentuÃ©s ou des espaces.
Merci de bien vouloir le renommer avant de continuer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="343"/>
        <source>NON DISPO : {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1371"/>
        <source>point N° {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1593"/>
        <source>Evolution de l&apos;abscisse du point {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1593"/>
        <source>Evolution de l&apos;ordonnée du point {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1593"/>
        <source>Evolution de la vitesse du point {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1640"/>
        <source>Pointage des positions&#xa0;: cliquer sur le point N° {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2088"/>
        <source>Désolé pas de fichier d&apos;aide pour le langage {0}.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1976"/>
        <source>fichiers vidéos (*.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2054"/>
        <source>Veuillez choisir une image (et définir l&apos;échelle)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="2143"/>
        <source>Pymecavideo n&apos;arrive pas à lire l&apos;image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="882"/>
        <source>Fichier Python créé</source>
        <translation>Creacion del archivo Python</translation>
    </message>
</context>
<context>
    <name>self.app</name>
    <message>
        <location filename="../../src/cadreur.py" line="56"/>
        <source>Presser la touche ESC pour sortir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/echelle.py" line="159"/>
        <source>Choisir le nombre de points puis Â«Â&#xa0;DÃ©marrer l&apos;acquisitionÂ&#xa0;Â» </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/echelle.py" line="164"/>
        <source>Vous pouvez continuer votre acquisition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="47"/>
        <source>Proximite de la souris {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="48"/>
        <source>; derniere video {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="49"/>
        <source>; videoDir {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cadreur.py" line="137"/>
        <source>Choisir le ralenti</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
